@@ -1,7 +1,7 @@
 package App::CSelUtils;
 
-our $DATE = '2016-08-27'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2016-09-01'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
@@ -246,7 +246,8 @@ sub ddsel {
     # skip root node itself
     require Scalar::Util;
     @matches = grep {
-        Scalar::Util::refaddr($_) ne Scalar::Util::refaddr($tree) } @matches;
+        Scalar::Util::refaddr($_) ne Scalar::Util::refaddr($tree) } @matches
+              unless @matches <= 1;
 
     for my $action (@$actions) {
         if ($action eq 'print') {
@@ -277,7 +278,7 @@ App::CSelUtils - Utilities related to Data::CSel
 
 =head1 VERSION
 
-This document describes version 0.05 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2016-08-27.
+This document describes version 0.06 of App::CSelUtils (from Perl distribution App-CSelUtils), released on 2016-09-01.
 
 =head1 DESCRIPTION
 
